## aioauth integration for FastAPI

- [aioauth_fastapi](https://github.com/aliev/aioauth-fastapi/tree/master/aioauth_fastapi): the core of FastAPI integration
- [aioauth_fastapi_demo](https://github.com/aliev/aioauth-fastapi/tree/master/aioauth_fastapi_demo): the demo project with [SQLAlchemy](https://www.sqlalchemy.org/) as an ORM and [sqlmodel](https://github.com/tiangolo/sqlmodel)
